import functools

from mapping import *


ADULT_SYMPTOM_MAP = [
    ('age', 'g5_04a', functools.partial(no_more_than, val=49)),
    ('sex', 'g5_02', two),
    ('s88881', 'g5_04a', functools.partial(less_than, val=32)),
    ('s88882', 'g5_04a', functools.partial(between, lower=32, upper=48.999)),
    ('s88883', 'g5_04a', functools.partial(between, lower=49, upper=64.999)),
    ('s88884', 'g5_04a', functools.partial(no_more_than, val=65)),
    ('s1', 'a1_01_1', one),
    ('s2', 'a1_01_2', one),
    ('s3', 'a1_01_3', one),
    ('s4', 'a1_01_4', one),
    ('s5', 'a1_01_5', one),
    ('s6', 'a1_01_6', one),
    ('s7', 'a1_01_7', one),
    ('s8', 'a1_01_8', one),
    ('s9', 'a1_01_9', one),
    ('s10', 'a1_01_10', one),
    ('s11', 'a1_01_11', one),
    ('s12', 'a1_01_12', one),
    ('s13', 'a1_01_13', one),
    ('s14', 'a1_01_14', one),
    ('s15', 'a2_01', functools.partial(no_more_than, val=30)),
    ('s16', 'a2_02', one),
    ('s17', 'a2_03', functools.partial(no_more_than, val=5)),
    ('s18991', 'a2_04', one),
    ('s18992', [('a2_19', 2), ('a2_19', 3)], has_any),
    ('s19991', 'a2_05', one),
    ('s19992', 'a2_05', two),
    ('s20', 'a2_06', one),
    ('s21', 'a2_07', one),
    ('s22', 'a2_08', functools.partial(no_more_than, val=10)),
    ('s23991', [('a2_09_1a', 1), ('a2_09_2a', 1)], has_any),
    ('s23992', [('a2_09_1a', 2), ('a2_09_2a', 2)], has_any),
    ('s23993', [('a2_09_1a', 3), ('a2_09_2a', 3)], has_any),
    ('s23994', [('a2_09_1a', 4), ('a2_09_2a', 4)], has_any),
    ('s27', 'a2_10', one),
    ('s28', 'a2_11', one),
    ('s29', 'a2_12', one),
    ('s30', 'a2_13', one),
    ('s31', 'a2_14', one),
    ('s32', 'a2_15', functools.partial(no_more_than, val=15)),
    ('s33', 'a2_16', one),
    ('s34', 'a2_17', one),
    ('s35', 'a2_18', one),
    ('s36991', 'a2_19', one),
    ('s36992', [('a2_19', 2), ('a2_19', 3)], has_any),
    ('s37', 'a2_20', one),
    ('s38', 'a2_21', one),
    ('s39', 'a2_22', functools.partial(no_more_than, val=22.5)),
    ('s40', 'a2_23', one),
    ('s41', 'a2_24', functools.partial(no_more_than, val=15)),
    ('s42', 'a2_25', one),
    ('s43', 'a2_26', functools.partial(no_more_than, val=7)),
    ('s44', 'a2_27', one),
    ('s45', 'a2_28', functools.partial(no_more_than, val=8)),
    ('s46', 'a2_29', one),
    ('s47', 'a2_30', one),
    ('s48', 'a2_31', one),
    ('s49', 'a2_32', one),
    ('s50', 'a2_33', functools.partial(no_more_than, val=23.5)),
    ('s51', 'a2_34', one),
    ('s52', 'a2_35', one),
    ('s53', 'a2_36', one),
    ('s54', 'a2_37', functools.partial(no_more_than, val=7)),
    ('s55991', 'a2_38', one),
    ('s55992', 'a2_38', two),
    ('s56991', [('a2_39_1', 1), ('a2_39_2', 1)], has_any),
    ('s56992', [('a2_39_1', 2), ('a2_39_2', 2)], has_any),
    ('s56993', [('a2_39_1', 3), ('a2_39_2', 3)], has_any),
    ('s56994', [('a2_39_1', 4), ('a2_39_2', 4)], has_any),
    ('s58', 'a2_40', one),
    ('s59', 'a2_41', functools.partial(no_more_than, val=4)),
    ('s60', 'a2_42', one),
    ('s61', 'a2_43', one),
    ('s62', 'a2_44', three),
    ('s63', 'a2_45', one),
    ('s64991', [('a2_46a', 1), ('a2_46a', 2)], has_any),
    ('s64992', 'a2_46a', three),
    ('s66', 'a2_47', one),
    ('s67', 'a2_48', functools.partial(no_more_than, val=5)),
    ('s68', 'a2_49', one),
    ('s69', 'a2_50', one),
    ('s70', 'a2_51', one),
    ('s71', 'a2_52', one),
    ('s72', 'a2_53', one),
    ('s73', 'a2_54', functools.partial(no_more_than, val=2)),
    ('s74', 'a2_55', one),
    ('s75', 'a2_56', one),
    ('s76', 'a2_57', one),
    ('s77', 'a2_58', functools.partial(no_more_than, val=8)),
    ('s78', 'a2_59', three),
    ('s79', 'a2_60', one),
    ('s80', 'a2_61', one),
    ('s81', 'a2_62', functools.partial(no_more_than, val=8)),
    ('s82991', [('a2_63_1', 2), ('a2_63_2', 2)], has_any),
    ('s84', 'a2_64', one),
    ('s85', 'a2_65', functools.partial(no_more_than, val=14)),
    ('s86', 'a2_66', two),
    ('s87', 'a2_67', one),
    ('s88', 'a2_68', functools.partial(no_more_than, val=90)),
    ('s89', 'a2_69', one),
    ('s90', 'a2_70', functools.partial(no_more_than, val=.5416667)),
    ('s91', 'a2_71', one),
    ('s92', 'a2_72', one),
    ('s93', 'a2_73', functools.partial(no_more_than, val=7)),
    ('s94', 'a2_74', one),
    ('s95', 'a2_75', one),
    ('s96', 'a2_76', functools.partial(no_more_than, val=.4166667)),
    ('s97', 'a2_77', one),
    ('s98', 'a2_78', one),
    ('s99', 'a2_79', functools.partial(no_more_than, val=4)),
    ('s100', 'a2_80', one),
    ('s101', 'a2_81', one),
    ('s102', 'a2_82', one),
    ('s103', 'a2_83', functools.partial(no_more_than, val=.0208333)),
    ('s104', 'a2_84', one),
    ('s105', 'a2_85', one),
    ('s106', 'a2_86', functools.partial(no_more_than, val=15)),
    ('s107', 'a2_87_1', one),
    ('s108', 'a2_87_2', one),
    ('s109', 'a2_87_3', one),
    ('s110', 'a2_87_4', one),
    ('s111', 'a2_87_5', one),
    ('s112', 'a2_87_6', one),
    ('s113', 'a2_87_7', one),
    ('s114', 'a2_87_8', one),
    ('s115', 'a2_87_9', one),
    ('s116', 'a2_87_10a', one),
    ('s118', 'a3_01', one),
    ('s119', 'a3_02', one),
    ('s120', 'a3_03', one),
    ('s121', 'a3_04', one),
    ('s122', 'a3_05', one),
    ('s123', 'a3_06', one),
    ('s124', 'a3_07', one),
    ('s125', 'a3_08', functools.partial(no_more_than, val=84)),
    ('s126', 'a3_09', one),
    ('s127', 'a3_10', one),
    ('s128', 'a3_11', functools.partial(no_more_than, val=240)),
    ('s129', 'a3_12', one),
    ('s130', 'a3_13', one),
    ('s131', 'a3_14', one),
    ('s132', 'a3_15', one),
    ('s133', 'a3_16', functools.partial(no_more_than, val=.3541667)),
    ('s134', 'a3_17', one),
    ('s135', 'a3_18', one),
    ('s136', 'a3_19', one),
    ('s137', 'a3_20', one),
    ('s138', 'a4_01', one),
    ('s139', 'a4_02_1', one),
    ('s140', 'a4_02_2', one),
    ('s141', 'a4_02_3', one),
    ('s142', 'a4_02_4', one),
    ('s143', 'a4_02_5a', one),
    ('s145', 'a4_02_6', one),
    ('s146', 'a4_02_7', one),
    ('s147', 'a4_03', functools.partial(no_more_than, val=4)),
    ('s148', 'a4_04', functools.partial(no_more_than, val=10)),
    ('s149', 'a4_05', one),
    ('s150', 'a4_06', one),
    ('s151', 'a5_01_1', one),
    ('s152', 'a5_01_2', one),
    ('s153', 'a5_01_3', one),
    ('s154', 'a5_01_4', one),
    ('s155', 'a5_01_5', one),
    ('s156', 'a5_01_6', one),
    ('s157', 'a5_01_7', one),
    ('s158', 'a5_01_8', one),
    ('s159', 'a5_01_9a', one),
    ('s161', 'a5_02', one),
    ('s162', 'a5_03', one),
    ('s163', 'a5_04', one),
]

CHILD_SYMPTOM_MAP = [
    ('age', 'g5_04a', functools.partial(no_more_than, val=2)),
    ('sex', 'g5_02', two),
    ('s3', 'g5_04b', one),
    ('s4', 'g5_04c', one),
    ('s5991', 'c1_01', two),
    ('s6991', [('c1_02', 2), ('c1_02', 3)], has_any),
    ('s7', 'c1_03', one),
    ('s8991', 'c1_04', one),
    ('s8992', 'c1_04', two),
    ('s9', 'c1_05', functools.partial(no_more_than, val=1000)),
    ('s11991', [('c1_06a', 4), ('c1_06a', 5)], has_any),
    ('s13', [('c1_07', 1), ('c1_07', 2)], has_any),
    ('s14', 'c1_08b', functools.partial(no_more_than, val=1000)),
    ('s16991', 'c1_11', two),
    ('s17', 'c1_12', one),
    ('s18', 'c1_13', one),
    ('s19', 'c1_14', one),
    ('s28', 'c1_20', functools.partial(no_more_than, val=270)),
    ('s29991', 'g5_04a', functools.partial(less_than, val=.41667)),
    ('s29992', 'g5_04a', functools.partial(between, lower=.41667, upper=.999)),
    ('s29993', 'g5_04a', functools.partial(between, lower=1, upper=2.999)),
    ('s29994', 'g5_04a', functools.partial(between, lower=3, upper=6.999)),
    ('s29995', 'g5_04a', functools.partial(no_more_than, val=7)),
    ('s30', [('c1_22a', 3), ('c1_22a', 4), ('c1_22a', 5)], has_any),
    ('s31', 'c1_25', functools.partial(no_more_than, val=300)),
    ('s110', 'c4_01', one),
    ('s111', 'c4_02', functools.partial(no_more_than, val=5)),
    ('s112', 'c4_03', one),
    ('s113991', 'c4_04', three),
    ('s114991', [('c4_05', 4), ('c4_05', 5)], has_any),
    ('s115', 'c4_06', one),
    ('s116991', 'c4_07b', one),
    ('s117', 'c4_08', functools.partial(no_more_than, val=3)),
    ('s118', 'c4_09', one),
    ('s119', 'c4_10', functools.partial(no_more_than, val=2)),
    ('s120', 'c4_11', one),
    ('s121', 'c4_12', one),
    ('s122', 'c4_13', functools.partial(no_more_than, val=7)),
    ('s123', 'c4_14', one),
    ('s124', 'c4_15', one),
    ('s125', 'c4_16', one),
    ('s126', 'c4_17', functools.partial(no_more_than, val=3)),
    ('s127', 'c4_18', one),
    ('s128', 'c4_19', functools.partial(no_more_than, val=3)),
    ('s129', 'c4_20', one),
    ('s130', 'c4_22', one),
    ('s131', 'c4_23', one),
    ('s132', 'c4_24', one),
    ('s133', 'c4_25', one),
    ('s134', 'c4_26', one),
    ('s135991', 'c4_27', three),
    ('s136', 'c4_28', one),
    ('s137', 'c4_29', one),
    ('s138', 'c4_30', one),
    ('s139991', 'c4_31_1', one),
    ('s141991', 'c4_32', one),
    ('s142', 'c4_33', functools.partial(no_more_than, val=5)),
    ('s143', 'c4_34', one),
    ('s144', 'c4_35', one),
    ('s145', 'c4_36', one),
    ('s146', 'c4_37', functools.partial(no_more_than, val=3.5)),
    ('s147', 'c4_38', one),
    ('s148', 'c4_39', one),
    ('s149', 'c4_40', one),
    ('s150', 'c4_41', one),
    ('s151', 'c4_42', one),
    ('s152', 'c4_43', one),
    ('s153', 'c4_44', one),
    ('s154', 'c4_46', one),
    ('s155', 'c4_47_1', one),
    ('s156', 'c4_47_2', one),
    ('s157', 'c4_47_3', one),
    ('s158', 'c4_47_4', one),
    ('s159', 'c4_47_5', one),
    ('s160', 'c4_47_6', one),
    ('s161', 'c4_47_7', one),
    ('s162', 'c4_47_8a', one),
    ('s163', 'c4_47_9', one),
    ('s164', 'c4_47_11', one),
    ('s165', 'c4_48', one),
    ('s166', 'c4_49', one),
    ('s188', 'c5_17', one),
    ('s189', 'c5_18', one),
    ('s190', 'c5_19', one),
    ('s180', None, definitely_not),
    ('s181', None, definitely_not),
]

NEONATE_SYMPTOM_MAP = [
    ('age', 'g5_04c', functools.partial(no_more_than, val=3)),
    ('sex', 'g5_02', one),
    ('s3', 'g5_04b', one),
    ('s5_1', 'c1_01', one),
    ('s6_1', 'c1_02', one),
    ('s7', 'c1_03', one),
    ('s8', 'c1_04', one),
    ('s9', 'c1_05', functools.partial(no_more_than, val=2)),
    ('s11', 'c1_06a', one),
    ('s13_1', 'c1_07', one),
    ('s14', 'c1_08b', functools.partial(no_more_than, val=2500)),
    ('s15', 'c1_09', one),
    ('s16_1', 'c1_11', one),
    ('s17', 'c1_12', one),
    ('s18', 'c1_13', one),
    ('s19', 'c1_14', one),
    ('s20', 'c1_15', one),
    ('s21', 'c1_16', one),
    ('s22', 'c1_17', one),
    ('s23', 'c1_18', one),
    ('s24', 'c1_19_1', one),
    ('s25', 'c1_19_2', one),
    ('s26', 'c1_19_3', one),
    ('s27', 'c1_19_4a', one),
    ('s28', 'c1_20', functools.partial(no_more_than, val=2)),
    ('s29', 'c1_21', functools.partial(no_more_than, val=3)),
    ('s30', 'c1_22a', one),
    ('s31', 'c1_25', functools.partial(no_more_than, val=3)),
    ('s32', 'c1_26', one),
    ('s33', 'c2_01_1', one),
    ('s34', 'c2_01_2', one),
    ('s35', 'c2_01_3', one),
    ('s36', 'c2_01_4', one),
    ('s37', 'c2_01_5', one),
    ('s38', 'c2_01_6', one),
    ('s39', 'c2_01_7', one),
    ('s40', 'c2_01_8', one),
    ('s41', 'c2_01_9', one),
    ('s42', 'c2_01_10', one),
    ('s43', 'c2_01_12', one),
    ('s45', 'c2_02', functools.partial(no_more_than, val=255)),
    ('s46', 'c2_03', one),
    ('s47', 'c2_04', one),
    ('s48', 'c2_05', functools.partial(no_more_than, val=.125)),
    ('s49', 'c2_06', one),
    ('s50', 'c2_07', one),
    ('s51', 'c2_08a', one),
    ('s52', 'c2_09', one),
    ('s53', 'c2_10', functools.partial(no_more_than, val=.20833)),
    ('s54', 'c2_11', one),
    ('s55', 'c2_12', one),
    ('s56', 'c2_13a', one),
    ('s57', 'c2_15a', one),
    ('s58', 'c2_17', one),
    ('s59', 'c2_18', one),
    ('s60', 'c3_01', one),
    ('s61', 'c3_02', one),
    ('s62', 'c3_03_1', one),
    ('s63', 'c3_03_2', one),
    ('s64', 'c3_03_3', one),
    ('s65', 'c3_04', one),
    ('s66', 'c3_05', one),
    ('s67', 'c3_06', one),
    ('s68', 'c3_07', one),
    ('s69', 'c3_08', one),
    ('s70', 'c3_09', one),
    ('s71', 'c3_10', one),
    ('s72', 'c3_11', one),
    ('s73', 'c3_12', one),
    ('s74', 'c3_13', one),
    ('s75', 'c3_14', functools.partial(no_more_than, val=2)),
    ('s76', 'c3_15', one),
    ('s77', 'c3_16', one),
    ('s78', 'c3_17', one),
    ('s79', 'c3_18', functools.partial(no_more_than, val=2)),
    ('s80', 'c3_19', functools.partial(no_more_than, val=2)),
    ('s81', 'c3_20', one),
    ('s82', 'c3_21', functools.partial(no_more_than, val=2)),
    ('s83', 'c3_22', functools.partial(no_more_than, val=2)),
    ('s84', 'c3_23', one),
    ('s85', 'c3_24', one),
    ('s86', 'c3_25', one),
    ('s87', 'c3_26', one),
    ('s88', 'c3_27', functools.partial(no_more_than, val=3)),
    ('s89', 'c3_28', functools.partial(no_more_than, val=2)),
    ('s90', 'c3_29', one),
    ('s91', 'c3_30', functools.partial(no_more_than, val=3)),
    ('s92', 'c3_31', functools.partial(no_more_than, val=2)),
    ('s93', 'c3_32', one),
    ('s94', 'c3_33', one),
    ('s95', 'c3_34', one),
    ('s96', 'c3_35', one),
    ('s97', 'c3_36', one),
    ('s98', 'c3_37', one),
    ('s99', 'c3_38', one),
    ('s100', 'c3_39', one),
    ('s101', 'c3_40', one),
    ('s102', 'c3_41', one),
    ('s103', 'c3_42', one),
    ('s104', 'c3_44', one),
    ('s105_1', 'c3_45b', one),
    ('s106', 'c3_46', one),
    ('s107', 'c3_47', one),
    ('s108', 'c3_48', one),
    ('s109', 'c3_49', one),
    ('s188', 'c5_17', one),
    ('s189', 'c5_18', one),
    ('s190', 'c5_19', one),
    ('s180', None, definitely_not),
    ('s181', None, definitely_not),
]

TARIFF_HCE_COLUMNS = {
    'adult': [
        's1',
        's2',
        's3',
        's4',
        's5',
        's6',
        's7',
        's8',
        's9',
        's10',
        's11',
        's12',
        's13',
        's14',
    ],
    'child': [
        's180',
        's181',
    ],
    'neonate': [
        's180',
        's181',
    ],
}

TARIFF_SYMPTOM_MAP = {
    'adult': ADULT_SYMPTOM_MAP,
    'child': CHILD_SYMPTOM_MAP,
    'neonate': NEONATE_SYMPTOM_MAP,
}


if __name__ == '__main__':
    map_all_modules('tariff', TARIFF_SYMPTOM_MAP, TARIFF_HCE_COLUMNS)
